A package for generating and checking prime numbers.
Functions:

`g(m)` - Generates prime numbers up to `m`, returns [`list`](https://docs.python.org/3.8/library/functions.html#func-list).

`p(x)` - Checks if `x` is prime, returns [`bool`](https://docs.python.org/3.8/library/functions.html#bool).